@@ -297,6 +297,8 @@ class ClassifierPredictionSummaryComponent(ExplainerComponent):
         Shows the predicted probability for each {self.explainer.target} label.
         """
 
+        self.register_dependencies("metrics")
+
     def layout(self):
         return dbc.Card([
             make_hideable(
@@ -388,7 +390,8 @@ class PrecisionComponent(ExplainerComponent):
                     subtitle="Does fraction positive increase with predicted probability?",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
                     hide_cutoff=False, hide_binsize=False, hide_binmethod=False,
-                    hide_multiclass=False, hide_selector=False, pos_label=None,
+                    hide_multiclass=False, hide_selector=False, hide_popout=False, 
+                    pos_label=None,
                     bin_size=0.1, quantiles=10, cutoff=0.5,
                     quantiles_or_binsize='bin_size', multiclass=False, description=None, 
                     **kwargs):
@@ -412,6 +415,7 @@ class PrecisionComponent(ExplainerComponent):
             hide_binmethod (bool, optional): Hide binsize/quantiles toggle. Defaults to False.
             hide_multiclass (bool, optional): Hide multiclass toggle. Defaults to False.
             hide_selector (bool, optional): Hide pos label selector. Default to True.
+            hide_popout (bool, optional): hide popout button
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             bin_size (float, optional): Size of bins in probability space. Defaults to 0.1.
             quantiles (int, optional): Number of quantiles to divide plot. Defaults to 10.
@@ -426,6 +430,8 @@ class PrecisionComponent(ExplainerComponent):
         self.cutoff_name = 'precision-cutoff-' + self.name
 
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
+        
+
         if self.description is None: self.description = f"""
         On this plot you can see the relation between the predicted probability
         that a {self.explainer.index_name} belongs to the positive class, and
@@ -436,6 +442,8 @@ class PrecisionComponent(ExplainerComponent):
         from the bottom left corner to the top right corner. A strong model would
         classify most observations correctly and close to 0% or 100% probability.
         """
+        self.popout = GraphPopout('precision-'+self.name+'popout', 'precision-graph-'+self.name, 
+                            self.title, self.description)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
     def layout(self):
@@ -461,6 +469,12 @@ class PrecisionComponent(ExplainerComponent):
                         ], style={'margin': 0}),
                     ])
                 ]),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -578,9 +592,18 @@ class PrecisionComponent(ExplainerComponent):
              Input('precision-cutoff-'+self.name, 'value'),
              Input('precision-multiclass-'+self.name, 'value'),
              Input('pos-label-'+self.name, 'value')],
-            #[State('tabs', 'value')],
+            [State('precision-graph-'+self.name, 'figure')],
         )
-        def update_precision_graph(bin_size, quantiles, bins, cutoff, multiclass, pos_label):
+        def update_precision_graph(bin_size, quantiles, bins, cutoff, multiclass, pos_label, fig):
+            ctx = dash.callback_context
+            trigger = ctx.triggered[0]['prop_id'].split('.')[0]
+            if trigger == 'precision-cutoff-'+self.name and fig is not None:
+                return go.Figure(fig).update_shapes(dict(
+                    type='line',
+                    xref='x', yref='y2',
+                    x0=cutoff, x1=cutoff,
+                    y0=0, y1=1.0,
+                 ))
             if bins == 'bin_size':
                 return self.explainer.plot_precision(
                     bin_size=bin_size, cutoff=cutoff, 
@@ -597,7 +620,7 @@ class ConfusionMatrixComponent(ExplainerComponent):
                     subtitle="How many false positives and false negatives?",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
                     hide_cutoff=False, hide_percentage=False, hide_binary=False,
-                    hide_selector=False, pos_label=None,
+                    hide_selector=False, hide_popout=False, pos_label=None,
                     cutoff=0.5, percentage=True, binary=True, description=None,
                     **kwargs):
         """Display confusion matrix component
@@ -618,6 +641,7 @@ class ConfusionMatrixComponent(ExplainerComponent):
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
             hide_binary (bool, optional): Hide binary toggle. Defaults to False.
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Default cutoff. Defaults to 0.5.
             percentage (bool, optional): Display percentages instead of counts. Defaults to True.
@@ -644,7 +668,9 @@ class ConfusionMatrixComponent(ExplainerComponent):
         """
 
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
-        self.register_dependencies("preds", "pred_probas", "pred_percentiles")
+        self.popout = GraphPopout('confusionmatrix-'+self.name+'popout', 'confusionmatrix-graph-'+self.name, 
+                            self.title, self.description)
+        self.register_dependencies("preds", "pred_probas", "pred_percentiles", "confusion_matrix")
 
     def layout(self):
         return dbc.Card([
@@ -662,7 +688,13 @@ class ConfusionMatrixComponent(ExplainerComponent):
                         dbc.Col([self.selector.layout()], width=3), hide=self.hide_selector)
                 ], justify="end"),
                 dcc.Graph(id='confusionmatrix-graph-'+self.name,
-                                            config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
+                                config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -735,8 +767,10 @@ class LiftCurveComponent(ExplainerComponent):
     def __init__(self, explainer, title="Lift Curve", name=None,
                     subtitle="Performance how much better than random?",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
-                    hide_cutoff=False, hide_percentage=False, hide_selector=False,
-                    pos_label=None, cutoff=0.5, percentage=True, description=None,
+                    hide_cutoff=False, hide_percentage=False, hide_wizard=False,
+                    hide_selector=False, hide_popout=False, pos_label=None, 
+                    cutoff=0.5, percentage=True, 
+                    wizard=True, description=None,
                     **kwargs):
         """Show liftcurve component
 
@@ -754,10 +788,13 @@ class LiftCurveComponent(ExplainerComponent):
             hide_footer (bool, optional): hide the footer at the bottom of the component
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
+            hide_wizard (bool, optional): hide the wizard toggle. Defaults to False.
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Cutoff for lift curve. Defaults to 0.5.
             percentage (bool, optional): Display percentages instead of counts. Defaults to True.
+            wizard (bool, optional): display the wizard in the graph.
             description (str, optional): Tooltip to display when hover over
                 component title. When None default text is shown. 
         """
@@ -766,12 +803,16 @@ class LiftCurveComponent(ExplainerComponent):
         self.cutoff_name = 'liftcurve-cutoff-' + self.name
 
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
+        
         if self.description is None: self.description = """
         The lift curve shows you the percentage of positive classes when you only
         select observations with a score above cutoff vs selecting observations
         randomly. This shows you how much better the model is than random (the lift).
         """
-        self.register_dependencies("preds", "pred_probas", "pred_percentiles")
+
+        self.popout = GraphPopout('liftcurve-'+self.name+'popout', 'liftcurve-graph-'+self.name, 
+                        self.title, self.description)
+        self.register_dependencies("get_liftcurve_df")
 
     def layout(self):
         return dbc.Card([
@@ -792,6 +833,12 @@ class LiftCurveComponent(ExplainerComponent):
                     dcc.Graph(id='liftcurve-graph-'+self.name,
                                 config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
                 ], style={'margin': 0}),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -827,6 +874,21 @@ class LiftCurveComponent(ExplainerComponent):
                             ),
                         ]),
                     ]), hide=self.hide_percentage),  
+                make_hideable(
+                    html.Div([
+                        dbc.FormGroup([
+                            dbc.Tooltip("Display how a perfect model would perform"
+                                    "(the so-called 'wizard')",
+                                    target='liftcurve-wizard-'+self.name),
+                            dbc.Checklist(
+                                options=[{"label":  "Display wizard", "value": True}],
+                                value=[True] if self.wizard else [],
+                                id='liftcurve-wizard-'+self.name,
+                                inline=True,
+                                switch=True,
+                            ),
+                        ]),
+                    ]), hide=self.hide_wizard),  
             ]), hide=self.hide_footer)
         ])
 
@@ -835,18 +897,20 @@ class LiftCurveComponent(ExplainerComponent):
             Output('liftcurve-graph-'+self.name, 'figure'),
             [Input('liftcurve-cutoff-'+self.name, 'value'),
              Input('liftcurve-percentage-'+self.name, 'value'),
+             Input('liftcurve-wizard-'+self.name, 'value'),
              Input('pos-label-'+self.name, 'value')],
         )
-        def update_precision_graph(cutoff, percentage, pos_label):
+        def update_precision_graph(cutoff, percentage, add_wizard, pos_label):
             return self.explainer.plot_lift_curve(cutoff=cutoff, 
-                percentage=bool(percentage), pos_label=pos_label)
+                percentage=bool(percentage), pos_label=pos_label, 
+                add_wizard=bool(add_wizard))
 
 
 class CumulativePrecisionComponent(ExplainerComponent):
     def __init__(self, explainer, title="Cumulative Precision", name=None,
                     subtitle="Expected distribution for highest scores",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
-                    hide_selector=False, pos_label=None,
+                    hide_selector=False, hide_popout=False, pos_label=None,
                     hide_cutoff=False, cutoff=None,
                     hide_percentile=False, percentile=None, description=None,
                     **kwargs):
@@ -865,6 +929,7 @@ class CumulativePrecisionComponent(ExplainerComponent):
             hide_subtitle (bool, optional): Hide subtitle. Defaults to False.
             hide_footer (bool, optional): hide the footer at the bottom of the component
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             
         """
@@ -877,7 +942,10 @@ class CumulativePrecisionComponent(ExplainerComponent):
         This plot shows the percentage of each label that you can expect when you
         only sample the top x% highest scores. 
         """
-        self.register_dependencies("preds", "pred_probas", "pred_percentiles")
+        self.popout = GraphPopout('cumulative-precision-'+self.name+'popout', 
+                        'cumulative-precision-graph-'+self.name, 
+                        self.title, self.description)
+        self.register_dependencies("get_liftcurve_df")
 
     def layout(self):
         return dbc.Card([
@@ -894,6 +962,12 @@ class CumulativePrecisionComponent(ExplainerComponent):
                     dcc.Graph(id='cumulative-precision-graph-'+self.name,
                                 config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
                 ], style={'margin': 0}),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -967,6 +1041,7 @@ class ClassificationComponent(ExplainerComponent):
                     subtitle="Distribution of labels above and below cutoff",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
                     hide_cutoff=False, hide_percentage=False, hide_selector=False,
+                    hide_popout=False, 
                     pos_label=None, cutoff=0.5, percentage=True, description=None,
                     **kwargs):
         """Shows a barchart of the number of classes above the cutoff and below
@@ -987,6 +1062,7 @@ class ClassificationComponent(ExplainerComponent):
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_percentage (bool, optional): Hide percentage toggle. Defaults to False.
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): Cutoff for prediction. Defaults to 0.5.
             percentage (bool, optional): Show percentage instead of counts. Defaults to True.
@@ -998,9 +1074,14 @@ class ClassificationComponent(ExplainerComponent):
         self.cutoff_name = 'classification-cutoff-' + self.name
 
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
+        
+
         if self.description is None: self.description = """
         Plot showing the fraction of each class above and below the cutoff.
         """
+
+        self.popout = GraphPopout('classification-'+self.name+'popout', 
+                            'classification-graph-'+self.name, self.title, self.description)
         self.register_dependencies("preds", "pred_probas", "pred_percentiles")
 
     def layout(self):
@@ -1022,6 +1103,12 @@ class ClassificationComponent(ExplainerComponent):
                     dcc.Graph(id='classification-graph-'+self.name,
                                 config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
                 ], style={'margin': 0}),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -1075,7 +1162,7 @@ class RocAucComponent(ExplainerComponent):
     def __init__(self, explainer, title="ROC AUC Plot", name=None, 
                     subtitle="Trade-off between False positives and false negatives",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
-                    hide_cutoff=False, hide_selector=False,
+                    hide_cutoff=False, hide_selector=False, hide_popout=False, 
                     pos_label=None, cutoff=0.5, description=None,
                     **kwargs):
         """Show ROC AUC curve component
@@ -1094,6 +1181,7 @@ class RocAucComponent(ExplainerComponent):
             hide_footer (bool, optional): hide the footer at the bottom of the component
             hide_cutoff (bool, optional): Hide cutoff slider. Defaults to False.
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): default cutoff. Defaults to 0.5.
 
@@ -1103,9 +1191,12 @@ class RocAucComponent(ExplainerComponent):
         self.cutoff_name = 'rocauc-cutoff-' + self.name
         
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
+        
         if self.description is None: self.description = """
         """
-        self.register_dependencies("preds", "pred_probas", "pred_percentiles")
+        self.popout = GraphPopout('rocauc-'+self.name+'popout', 
+                            'rocauc-graph-'+self.name, self.title, self.description)
+        self.register_dependencies("preds", "pred_probas", "pred_percentiles", "roc_auc_curve")
 
     def layout(self):
         return dbc.Card([
@@ -1124,6 +1215,12 @@ class RocAucComponent(ExplainerComponent):
                     ], justify="end"),
                 dcc.Graph(id='rocauc-graph-'+self.name,
                         config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
@@ -1160,7 +1257,7 @@ class PrAucComponent(ExplainerComponent):
     def __init__(self, explainer, title="PR AUC Plot", name=None,
                     subtitle="Trade-off between Precision and Recall",
                     hide_title=False, hide_subtitle=False, hide_footer=False,
-                    hide_cutoff=False, hide_selector=False,
+                    hide_cutoff=False, hide_selector=False, hide_popout=False, 
                     pos_label=None, cutoff=0.5, description=None,
                     **kwargs):
         """Display PR AUC plot component
@@ -1179,6 +1276,7 @@ class PrAucComponent(ExplainerComponent):
             hide_footer (bool, optional): hide the footer at the bottom of the component
             hide_cutoff (bool, optional): hide cutoff slider. Defaults to False.
             hide_selector(bool, optional): hide pos label selector. Defaults to False.
+            hide_popout (bool, optional): hide popout button. Defaults to False.
             pos_label ({int, str}, optional): initial pos label. Defaults to explainer.pos_label
             cutoff (float, optional): default cutoff. Defaults to 0.5.
             description (str, optional): Tooltip to display when hover over
@@ -1189,10 +1287,13 @@ class PrAucComponent(ExplainerComponent):
         self.cutoff_name = 'prauc-cutoff-' + self.name
 
         self.selector = PosLabelSelector(explainer, name=self.name, pos_label=pos_label)
+        
         if self.description is None: self.description = """
         Show the trade-off between Precision and Recall in one plot.
         """
-        self.register_dependencies("preds", "pred_probas", "pred_percentiles")
+        self.popout = GraphPopout('prauc-'+self.name+'popout', 
+                    'prauc-graph-'+self.name, self.title, self.description)
+        self.register_dependencies("preds", "pred_probas", "pred_percentiles", "pr_auc_curve")
 
     def layout(self):
         return dbc.Card([
@@ -1211,6 +1312,12 @@ class PrAucComponent(ExplainerComponent):
                     ], justify="end"),
                 dcc.Graph(id='prauc-graph-'+self.name,
                         config=dict(modeBarButtons=[['toImage']], displaylogo=False)),
+                dbc.Row([
+                    make_hideable(
+                        dbc.Col([
+                            self.popout.layout()
+                        ], md=2, align="start"), hide=self.hide_popout),
+                ], justify="end"),
             ]),
             make_hideable(
             dbc.CardFooter([
